@@ -14,7 +14,7 @@ def manage():
     env_path = Path('.') / '.crm'
     load_dotenv(dotenv_path=env_path)
 
-    os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION'))
+    os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 
     from configurations.management import execute_from_command_line
     execute_from_command_line(sys.argv)
