@@ -15,7 +15,7 @@ from pathlib import Path  # python3 only
 env_path = Path('.') / '.crm'
 load_dotenv(dotenv_path=env_path)
 
-os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION'))
+os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 
 
 # os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.dev_settings')
